@@ -38,7 +38,7 @@ fi
 
 function test_file {
 
-if [ -f sql/sigs/pgrouting--$1.sig ]
+if [ -f "sql/sigs/pgrouting--$1.sig" ]
 then
     echo "- [x] sql/sigs/pgrouting--$1.sig"
 else
@@ -51,48 +51,24 @@ fi
 #---------------------------------------------------------------------
 
 
-if [[ -z  $1 ]]; then
-    echo "Mayor missing";
-    echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
-    exit 1;
-fi
-if [[ -z  $2 ]]; then
-    echo "Minor missing";
-    echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
-    exit 1;
-fi
-
-if [[ -z  $3 ]]; then
-    echo "Micro missing";
-    echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
-    exit 1;
-fi
-
-if [[ -z  $4 ]]; then
-    echo "Last Micro missing";
-    echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
-    exit 1;
-fi
-
-
-if [[ -z  $5 ]]; then
-    echo "branch missing";
-    echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
-    exit 1;
-fi
-
-MAYOR=$1
-MINOR=$2
-MICRO=$3
-PREV_REL=$4
-BRANCH=$5
-DEBUG=$6
-RC=$7
+MAYOR=3
+MINOR=0
+MICRO=2
+RC=""
+PREV_REL=3.0.0
+PREV_RELS="
+    3.0.1 3.0.0
+    2.6.3 2.6.2 2.6.1 2.6.0
+    "
+# These releases are not for update
+OLD_RELS="
+    2.5.4 2.5.3 2.5.2 2.5.1 2.5.0
+    2.4.2 2.4.1 2.4.0
+    2.3.2 2.3.1 2.3.0
+    2.2.4 2.2.3 2.2.2 2.2.1 2.2.0
+    2.1.0
+    2.0.1 2.0.0"
+DEBUG=$1
 
 
 if [[ -z  "$DEBUG" ]]; then
@@ -102,20 +78,6 @@ fi
 echo - [x] No files changed before execution.
 echo
 
-#---------------------------------------------------------------------
-echo "### Verify branch to be $BRANCH"
-echo
-#---------------------------------------------------------------------
-
-GIT_BRANCH="$(git rev-parse --abbrev-ref HEAD)"
-
-if [[ "$GIT_BRANCH" == "$BRANCH" ]]; then
-    echo "- [x] Already in branch $BRANCH";
-    echo
-else
-    error_msg "Current Branch is not: $BRANCH"
-    exit 1
-fi
 
 #---------------------------------------------------------------------
 echo
@@ -156,22 +118,23 @@ if [[ -n $DEBUG ]]; then
     echo
 fi
 
-CURRENTNEWS=$(grep $MAYOR.$MINOR.$MICRO doc/src/release_notes.rst | grep ref)
-if [[ $? != 0 ]]; then
-    error_msg "Section $MAYOR.$MINOR.$MICRO in release_notes.rst file is missing"
+if ! grep $MAYOR.$MINOR.$MICRO doc/src/release_notes.rst > /dev/null; then
+    rror_msg "Section $MAYOR.$MINOR.$MICRO in release_notes.rst file is missing"
     exit 1
 else
     echo "- [x] release_notes.rst section $MAYOR.$MINOR.$MICRO exists"
 fi
 
 
-OLDNEWS=$(grep $PREV_REL doc/src/release_notes.rst | grep ref)
-if [[ $? != 0 ]]; then
-    error_msg "Section $PREV_REL in release_notes.rst file is missing"
-    exit 1
-else
-    echo "- [x] release_notes.rst section $PREV_REL exists"
-fi
+for r in $PREV_RELS $OLD_RELS
+do
+    if ! grep "${r}" doc/src/release_notes.rst > /dev/null; then
+        error_msg "Section $r in release_notes.rst file is missing"
+        exit 1
+    else
+        echo "- [x] release_notes.rst section $r exists"
+    fi
+done
 
 
 tools/release-scripts/notes2news.pl
@@ -196,36 +159,20 @@ echo "- CMakeLists"
 
 if [[ -n $DEBUG ]]; then
     echo "\`\`\`"
-    echo "cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_MAJOR \"$MAYOR\")'"
-    echo "cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_MINOR \"$MINOR\")'"
-    echo "cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_PATCH \"$MICRO\")'"
+    echo "grep -Po '(?<=project\(PGROUTING VERSION )[^;]+' CMakeLists.txt"
     echo "cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_DEV \"$RC\")'"
     echo "\`\`\`"
 fi
 
-if [[ $(cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_MAJOR' | grep $MAYOR) != "set(PGROUTING_VERSION_MAJOR \"$MAYOR\")" ]]; then
-    error_msg "FATAL: PGROUTING_VERSION_MAJOR is not '$MAYOR' ... Verify CMakeLists.txt"
+if [[ $(grep -Po '(?<=project\(PGROUTING VERSION )[^;]+' CMakeLists.txt) != "$MAYOR.$MINOR.$MICRO" ]]; then
+    error_msg "FATAL: PGROUTING_VERSION is not '$MAYOR.$MINOR.$MICRO' ... Verify CMakeLists.txt"
     exit 1
 else
-    echo "  - [x] mayor information is OK"
+    echo "  - [x] $MAYOR.$MINOR.$MICRO information is OK"
 fi
 
 
-if [[ $(cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_MINOR' | grep $MINOR) !=  "set(PGROUTING_VERSION_MINOR \"$MINOR\")" ]]; then
-    error_msg "FATAL: PGROUTING_VERSION_MINOR is not '$MINOR' ... Verify CMakeLists.txt"
-    exit 1
-else
-    echo "  - [x] Check minor information is OK"
-fi
-
-if [[ $(cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_PATCH' | grep $MICRO) !=  "set(PGROUTING_VERSION_PATCH \"$MICRO\")" ]]; then
-    error_msg "FATAL: PGROUTING_VERSION_PATCH is not '$MICRO' ... Verify CMakeLists.txt"
-    exit 1
-else
-    echo "  - [x] Check patch information is OK"
-fi
-
-if [[ $(cat CMakeLists.txt | grep 'set(PGROUTING_VERSION_DEV' ) !=  "set(PGROUTING_VERSION_DEV \"$RC\")" ]]; then
+if [[ $(grep 'set(PGROUTING_VERSION_DEV' CMakeLists.txt ) !=  "set(PGROUTING_VERSION_DEV \"$RC\")" ]]; then
     error_msg "FATAL: PGROUTING_VERSION_DEV is not '$RC' ... Verify CMakeLists.txt"
     exit 1
 else
@@ -235,115 +182,48 @@ fi
 
 #---------------------------------------------------------------------
 
-echo "- src/common/test/doc-pgr_version.result"
+echo "- "docqueries/version/doc-version.result
 
 #---------------------------------------------------------------------
 
 if [[ -n $DEBUG ]]; then
     echo "\`\`\`"
-    echo "cat test/common/doc-pgr_version.result | grep \"$MAYOR.$MINOR.$MICRO\""
+    echo "grep '$MAYOR.$MINOR.$MICRO$RC' docqueries/version/doc-version.result"
     echo "\`\`\`"
 fi
 
-if [[ $(cat test/common/doc-pgr_version.result | grep "$MAYOR.$MINOR.$MICRO") != " $MAYOR.$MINOR.$MICRO" ]]; then
-    error_msg "test/common/doc-pgr_version.result is not $MAYOR.$MINOR.$MICRO"
+if [[ $(grep "$MAYOR.$MINOR.$MICRO$RC" docqueries/version/doc-version.result) != " $MAYOR.$MINOR.$MICRO$RC" ]]; then
+    error_msg "test/common/doc-pgr_version.result is not $MAYOR.$MINOR.$MICRO$RC"
     exit 1
 else
-    echo "  - [x]  src/common/test/doc-pgr_version.result"
+    echo "  - [x]  $MAYOR.$MINOR.$MICRO$RC in test/common/doc-pgr_version.result"
 fi
 
-#---------------------------------------------------------------------
-
-echo "- VERSION"
-
-#---------------------------------------------------------------------
-
-if [[ -n $DEBUG ]]; then
-    echo "\`\`\`"
-    echo "cat VERSION | grep \"release/$MAYOR.$MINOR\""
-    echo "\`\`\`"
-fi
-
-if [[ $(cat VERSION | grep "release/$MAYOR.$MINOR") != *"release/$MAYOR.$MINOR" ]]; then
-    error_msg "VERSION should have release/$MAYOR.$MINOR"
-    exit 1
-fi
-echo "  -[x] VERSION file branch: OK"
 
 #---------------------------------------------------------------------
 echo
 echo "### Checking signature files exist"
 echo
 #---------------------------------------------------------------------
-test_file 2.6.1
-test_file 2.6.0
-test_file 2.5.4
-test_file 2.5.3
-test_file 2.5.2
-test_file 2.5.1
-test_file 2.5.0
-test_file 2.4.2
-test_file 2.4.1
-test_file 2.4.0
-test_file 2.3.2
-test_file 2.3.1
-test_file 2.3.0
-test_file 2.2.4
-test_file 2.2.3
-test_file 2.2.2
-test_file 2.2.1
-test_file 2.2.0
-test_file 2.1.0
-test_file 2.0.1
-test_file 2.0.0
+test_file "$MAYOR.$MINOR.$MICRO"
+for r in $PREV_RELS
+do
+    test_file "$r"
+done
 
 
-#---------------------------------------------------------------------
-echo
-echo "### Locally make a clean build as Release"
-echo
-#---------------------------------------------------------------------
-if [[ -n $DEBUG ]]; then
-    echo "\`\`\`"
-    echo "bash tools/release-scripts/compile-release.sh 8   $MAYOR.$MINOR $MICRO"
-    echo "bash tools/release-scripts/compile-release.sh 4.8 $MAYOR.$MINOR $MICRO"
-    echo "\`\`\`"
-fi
-
-
-bash tools/release-scripts/compile-release.sh 8 $MAYOR.$MINOR $MICRO
-bash tools/release-scripts/compile-release.sh 4.8   $MAYOR.$MINOR $MICRO
-
-echo - [x] completed local builds
-
 #---------------------------------------------------------------------
 echo "### checking the signature files dont change"
 #---------------------------------------------------------------------
 
-sh tools/release-scripts/get_signatures.sh 2.6.1 ___sig_generate___ sql/sigs >> build/tmp_sigs.txt
-test_file 2.6.0
-test_file 2.5.4
-test_file 2.5.3
-test_file 2.5.2
-test_file 2.5.1
-test_file 2.5.0
-test_file 2.4.2
-test_file 2.4.1
-test_file 2.4.0
-test_file 2.3.2
-test_file 2.3.1
-test_file 2.3.0
-test_file 2.2.4
-test_file 2.2.3
-test_file 2.2.2
-test_file 2.2.1
-test_file 2.2.0
-test_file 2.1.0
-test_file 2.0.1
-test_file 2.0.0
+bash tools/release-scripts/compile-release.sh
+bash tools/release-scripts/get_signatures.sh
+if [[ -z $(git diff "sql/sigs/pgrouting--$MAYOR.$MINOR.$MICRO.sig") ]]; then
+    echo signature changed at: "sql/sigs/pgrouting--$MAYOR.$MINOR.$MICRO.sig"
+fi
 
 echo
-echo - [x] completed check: OK
+echo - [x] signature file "sql/sigs/pgrouting--$MAYOR.$MINOR.$MICRO.sig" is OK
 echo
 
 #---------------------------------------------------------------------
@@ -352,11 +232,14 @@ echo "### Locally run the update tester"
 echo "\`\`\`"
 echo bash tools/testers/update-tester.sh
 echo "\`\`\`"
-bash tools/testers/update-tester.sh
-if [[ $? != 0 ]]; then
-    echo "FATAL on the update-tester"
-    exit 1
-fi
+
+for r in ${PREV_RELS}
+do
+    if ! bash tools/testers/update-tester.sh "$r"; then
+        echo "FATAL updating from $r"
+        exit 1
+    fi
+done
 echo - [x] completed update testing
 
 
@@ -364,22 +247,35 @@ echo - [x] completed update testing
 echo "### execute the documentation queries"
 #---------------------------------------------------------------------
 echo "\`\`\`"
-echo tools/testers/algorithm-tester.pl -documentation
+echo tools/testers/doc_queries_generator.pl -documentation
 echo git status
 echo "\`\`\`"
-tools/testers/algorithm-tester.pl -documentation
-if [[ $? != 0 ]]; then
-    echo "FATAL errors found generating documentation result files"
-    exit 1
-fi
+tools/testers/doc_queries_generator.pl -documentation
 
-if [[ $(git status | grep 'Changes not staged for commit:') ]]; then
-    echo "FATAL: at least one result file changed"
+if [[ -z  "$DEBUG" ]]; then
+    git_no_change
+elif [[ $(git status | grep 'Changes not staged for commit:') ]]; then
+    echo "DEBUG WARNING: at least one file changed"
     git status
     exit 1
 fi
 
 echo - [x] No files changed
 
+#---------------------------------------------------------------------
+echo
+echo "### Locally make a clean build as Release"
+echo
+#---------------------------------------------------------------------
+
+
+if [[ -z  "$DEBUG" ]]; then
+    echo "\`\`\`"
+    echo "bash tools/release-scripts/compile-release.sh"
+    echo "\`\`\`"
+fi
+bash tools/release-scripts/compile-release.sh
+
+echo - [x] completed local builds
 
 echo "End of check"
